================
Light Controller
================


.. image:: https://img.shields.io/pypi/v/light_controller.svg
        :target: https://pypi.python.org/pypi/light_controller

.. image:: https://img.shields.io/travis/tcotte/light_controller.svg
        :target: https://travis-ci.com/tcotte/light_controller

.. image:: https://readthedocs.org/projects/light-controller/badge/?version=latest
        :target: https://light-controller.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




This package aims to manage lights thanks to the FG-PDV400W-24-8T with an UART connection protocol


* Free software: BSD license
* Documentation: https://light-controller.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
